// ======================================================================
//
// MenuBitmap.h
// jeff grills
//
// copyright 1997 origin systems inc
//
// ======================================================================

#ifndef MENU_BITMAP_H
#define MENU_BITMAP_H

// ======================================================================

class Bitmap;
class MenuResourceInteger;

#include "MenuElement.h"

// ======================================================================

class MenuBitmap : public MenuElement
{
protected:

	Bitmap      *bitmap;
	int          bitmapFrame;
	bool         ownsBitmap;
	bool         isMouse;

private:

	MenuBitmap(void);
	MenuBitmap(const MenuBitmap &);
	MenuBitmap &operator =(const MenuBitmap &);

public:

	MenuBitmap(MenuElement *parent, int maxWidth, int maxHeight, Iff *iff=NULL);
	virtual ~MenuBitmap(void);

	void load(Iff *iff);

	virtual Bitmap *getCurrentBitmap(void) const;

	virtual void     setCurrentFrame(int newBitmapFrame);
	virtual int      getCurrentFrame(void) const;

	virtual IoResult event(IoEventStruct *event);
	virtual void     menuDraw(int x, int y) const;
};

// --------------------------------------------------------------------

class MenuAnimatingBitmap : public MenuBitmap
{
public:

	enum AnimatingStyle
	{
		stop,
		forwardStop,
		backwardStop,
		forwardLooping,
		backwardLooping,
		pingPong,
		pingPongOnce
	};

private:

	MenuAnimatingBitmap(void);
	MenuAnimatingBitmap(const MenuAnimatingBitmap &);
	MenuAnimatingBitmap &operator =(const MenuAnimatingBitmap &);

protected:

	Timer          timer;
	int            notAnimatingFrame;
	AnimatingStyle animatingStyle;
	AnimatingStyle currentState;
	int            beginningEvent;
	int            endingEvent;
	int            startFrame;
	int            endFrame;
	int            step;

public:

	MenuAnimatingBitmap(MenuElement *parent, int maxWidth, int maxHeight, Iff *iff=NULL);
	virtual ~MenuAnimatingBitmap(void);

	virtual IoResult update(void);

	virtual void     menuEvent(int id, MenuElement *whom);

	void             load(Iff *iff);
};

// --------------------------------------------------------------------
// this class performs an animation like MenuAnimatingBitmap, except it
//  gets the current frame from a MenuResourceIntegerAnimation

class MenuAnimatingBitmap2 : public MenuBitmap
{
private:

	MenuResourceIntegerAnimation *integerAnimation;

private:

	MenuAnimatingBitmap2(void);
	MenuAnimatingBitmap2(const MenuAnimatingBitmap2 &);
	MenuAnimatingBitmap2 &operator =(const MenuAnimatingBitmap2 &);

public:

	MenuAnimatingBitmap2(MenuElement *parent, int maxWidth, int maxHeight, Iff *iff=NULL);
	virtual ~MenuAnimatingBitmap2(void);

	virtual int      getCurrentFrame(void) const;
	void             load(Iff *iff);
};

// --------------------------------------------------------------------

class MenuAnimatingBitmap3 : public MenuBitmap
{
private:

	MenuAnimatingBitmap3(void);
	MenuAnimatingBitmap3(const MenuAnimatingBitmap3 &);
	MenuAnimatingBitmap3 &operator =(const MenuAnimatingBitmap3 &);

protected:

	MenuResourceInteger *sharedInteger;
	int                 **animationSequence;
	int                 numSequences;
	int                 currentSequence;
	int                 currentFrame;
	Timer               timer;

public:

	MenuAnimatingBitmap3(MenuElement *parent, int maxWidth, int maxHeight, Iff *iff=NULL);
	virtual ~MenuAnimatingBitmap3(void);

	virtual IoResult update(void);

	void             load(Iff *iff);
};

// ======================================================================

#endif

